@@ -1,12 +1,12 @@
 package HTML::Strip::Whitespace;
-$HTML::Strip::Whitespace::VERSION = '0.2.1';
+$HTML::Strip::Whitespace::VERSION = '0.2.2';
 use strict;
 use warnings;
 
 use 5.016;
 
 package HTML::Strip::Whitespace::State;
-$HTML::Strip::Whitespace::State::VERSION = '0.2.1';
+$HTML::Strip::Whitespace::State::VERSION = '0.2.2';
 sub new
 {
     my $class = shift;
@@ -232,9 +232,14 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+HTML::Strip::Whitespace - Perl extension for stripping whitespace out of
+HTML.
+
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 SYNOPSIS
 
@@ -269,11 +274,6 @@ HTML. C<out> can be a reference to a buffer which will be filled with the
 stripped HTML, or alternatively a reference to a sub-routine or a file handle
 that will output it.
 
-=head1 NAME
-
-HTML::Strip::Whitespace - Perl extension for stripping whitespace out of
-HTML.
-
 =head1 FUNCTIONS
 
 =head2 html_strip_whitespace(source => $src, out => $out, strip_newlinews => $strip)
@@ -336,7 +336,7 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -373,14 +373,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Strip-Whitespace>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/HTML-Strip-Whitespace>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -452,7 +444,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Shlomi Fish.
+This software is Copyright (c) 2020 by Shlomi Fish.
 
 This is free software, licensed under:
 
